@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2008-2009, 2013-2017, 2019-2021 Rocky Bernstein <rocky@gnu.org>
+#
+#   Copyright (C) 2008-2009, 2013-2017, 2019-2021, 2023 Rocky
+#   Bernstein <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -35,12 +37,12 @@ if necessary, first.
 import sys
 
 from trepan import debugger as Mdebugger
-from trepan.post_mortem import post_mortem_excepthook, uncaught_exception
 from trepan.debugger import Trepan
+from trepan.post_mortem import post_mortem_excepthook, uncaught_exception
 
 
 def debugger_on_post_mortem():
-    """Call debugger on an exeception that terminates a program"""
+    """Call debugger on an exception that terminates a program"""
     sys.excepthook = post_mortem_excepthook
     return
 
@@ -69,7 +71,7 @@ def run_eval(
         return dbg.run_eval(
             expression, start_opts=start_opts, globals_=globals_, locals_=locals_
         )
-    except:
+    except Exception:
         dbg.core.trace_hook_suspend = True
         if start_opts and "tb_fn" in start_opts:
             tb_fn = start_opts["tb_fn"]
@@ -92,7 +94,7 @@ def run_call(func, *args, **kwds):
     dbg = Trepan()
     try:
         return dbg.run_call(func, *args, **kwds)
-    except:
+    except Exception:
         uncaught_exception(dbg)
         pass
     return
@@ -119,7 +121,7 @@ def run_exec(statement, debug_opts=None, start_opts=None, globals_=None, locals_
         return dbg.run_exec(
             statement, start_opts=start_opts, globals_=globals_, locals_=locals_
         )
-    except:
+    except Exception:
         uncaught_exception(dbg)
         pass
     return
@@ -127,85 +129,84 @@ def run_exec(statement, debug_opts=None, start_opts=None, globals_=None, locals_
 
 def debug(dbg_opts=None, start_opts=None, post_mortem=True, step_ignore=1, level=0):
     """
-Enter the debugger.
+    Enter the debugger.
 
-Parameters
-----------
+    Parameters
+    ----------
 
-level : how many stack frames go back. Usually it will be
-the default 0. But sometimes though there may be calls in setup to the debugger
-that you may want to skip.
+    level : how many stack frames go back. Usually it will be
+    the default 0. But sometimes though there may be calls in setup to the debugger
+    that you may want to skip.
 
-step_ignore : how many line events to ignore after the
-debug() call. 0 means don't even wait for the debug() call to finish.
+    step_ignore : how many line events to ignore after the
+    debug() call. 0 means don't even wait for the debug() call to finish.
 
-param dbg_opts : is an optional "options" dictionary that gets fed
-trepan.Debugger(); `start_opts' are the optional "options"
-dictionary that gets fed to trepan.Debugger.core.start().
+    param dbg_opts : is an optional "options" dictionary that gets fed
+    trepan.Debugger(); `start_opts' are the optional "options"
+    dictionary that gets fed to trepan.Debugger.core.start().
 
-Use like this:
+    Use like this:
 
-.. code-block:: python
+    .. code-block:: python
 
-    ... # Possibly some Python code
-    import trepan.api # Needed only once
-    ... # Possibly some more Python code
-    trepan.api.debug() # You can wrap inside conditional logic too
-    pass  # Stop will be here.
-    # Below is code you want to use the debugger to do things.
-    ....  # more Python code
-    # If you get to a place in the program where you aren't going
-    # want to debug any more, but want to remove debugger trace overhead:
-    trepan.api.stop()
+        ... # Possibly some Python code
+        import trepan.api # Needed only once
+        ... # Possibly some more Python code
+        trepan.api.debug() # You can wrap inside conditional logic too
+        pass  # Stop will be here.
+        # Below is code you want to use the debugger to do things.
+        ....  # more Python code
+        # If you get to a place in the program where you aren't going
+        # want to debug any more, but want to remove debugger trace overhead:
+        trepan.api.stop()
 
-Parameter "level" specifies how many stack frames go back. Usually it will be
-the default 0. But sometimes though there may be calls in setup to the debugger
-that you may want to skip.
+    Parameter "level" specifies how many stack frames go back. Usually it will be
+    the default 0. But sometimes though there may be calls in setup to the debugger
+    that you may want to skip.
 
-Parameter "step_ignore" specifies how many line events to ignore after the
-debug() call. 0 means don't even wait for the debug() call to finish.
+    Parameter "step_ignore" specifies how many line events to ignore after the
+    debug() call. 0 means don't even wait for the debug() call to finish.
 
-In situations where you want an immediate stop in the "debug" call
-rather than the statement following it ("pass" above), add parameter
-step_ignore=0 to debug() like this::
+    In situations where you want an immediate stop in the "debug" call
+    rather than the statement following it ("pass" above), add parameter
+    step_ignore=0 to debug() like this::
 
-    import trepan.api  # Needed only once
-    # ... as before
-    trepan.api.debug(step_ignore=0)
-    # ... as before
+        import trepan.api  # Needed only once
+        # ... as before
+        trepan.api.debug(step_ignore=0)
+        # ... as before
 
-Module variable _debugger_obj_ from module trepan.debugger is used as
-the debugger instance variable; it can be subsequently used to change
-settings or alter behavior. It should be of type Debugger (found in
-module trepan). If not, it will get changed to that type::
+    Module variable _debugger_obj_ from module trepan.debugger is used as
+    the debugger instance variable; it can be subsequently used to change
+    settings or alter behavior. It should be of type Debugger (found in
+    module trepan). If not, it will get changed to that type::
 
-   $ python
-   >>> from trepan.debugger import debugger_obj
-   >>> type(debugger_obj)
-   <type 'NoneType'>
-   >>> import trepan.api
-   >>> trepan.api.debug()
-   ...
-   (Trepan) c
-   >>> from trepan.debugger import debugger_obj
-   >>> debugger_obj
-   <trepan.debugger.Debugger instance at 0x7fbcacd514d0>
-   >>>
+       $ python
+       >>> from trepan.debugger import debugger_obj
+       >>> type(debugger_obj)
+       <type 'NoneType'>
+       >>> import trepan.api
+       >>> trepan.api.debug()
+       ...
+       (Trepan) c
+       >>> from trepan.debugger import debugger_obj
+       >>> debugger_obj
+       <trepan.debugger.Debugger instance at 0x7fbcacd514d0>
+       >>>
 
-If however you want your own separate debugger instance, you can
-create it from the debugger _class Debugger()_ from module
-trepan.debugger::
+    If however you want your own separate debugger instance, you can
+    create it from the debugger _class Debugger()_ from module
+    trepan.debugger::
 
-  $ python
-  >>> from trepan.debugger import Debugger
-  >>> dbgr = Debugger()  # Add options as desired
-  >>> dbgr
-  <trepan.debugger.Debugger instance at 0x2e25320>
+      $ python
+      >>> from trepan.debugger import Debugger
+      >>> dbgr = Debugger()  # Add options as desired
+      >>> dbgr
+      <trepan.debugger.Debugger instance at 0x2e25320>
 
-`dbg_opts' is an optional "options" dictionary that gets fed
-trepan.Debugger(); `start_opts' are the optional "options"
-dictionary that gets fed to trepan.Debugger.core.start().
-"""
+    `dbg_opts' is an optional "options" dictionary that gets fed
+    trepan.Debugger(); `start_opts' are the optional "options"
+    dictionary that gets fed to trepan.Debugger.core.start()."""
     if not isinstance(Mdebugger.debugger_obj, Mdebugger.Trepan):
         Mdebugger.debugger_obj = Mdebugger.Trepan(dbg_opts)
         Mdebugger.debugger_obj.core.add_ignore(debug, stop)
