@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2008-2010, 2013-2016, 2020 Rocky Bernstein <rocky@gnu.org>
+#
+#   Copyright (C) 2008-2010, 2013-2016, 2020 2023 Rocky Bernstein
+#   <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -23,22 +25,24 @@ handling what to do when an event is triggered."""
 
 
 # Common Python packages
-import os, sys, threading
+import os
 import os.path as osp
+import sys
+import threading
 
 # External packages
 import pyficache
 import tracer
 
+import trepan.clifns as Mclifns
+
 # Our local modules
 from trepan.lib import breakpoint, default, stack as Mstack
 from trepan.misc import option_set
-import trepan.clifns as Mclifns
-from trepan.processor import trace as Mtrace, cmdproc as Mcmdproc
+from trepan.processor import cmdproc as Mcmdproc, trace as Mtrace
 
 
 class TrepanCore(object):
-
     DEFAULT_INIT_OPTS = {
         "processor": None,
         # How many step events to skip before
@@ -49,7 +53,7 @@ class TrepanCore(object):
     }
 
     def __init__(self, debugger, opts=None):
-        """ Create a debugger object. But depending on the value of
+        """Create a debugger object. But depending on the value of
         key 'start' inside hash `opts', we may or may not initially
         start tracing events (i.e. enter the debugger).
 
@@ -139,7 +143,7 @@ class TrepanCore(object):
         return rc
 
     def canonic(self, filename):
-        """ Turns `filename' into its canonic representation and returns this
+        """Turns `filename' into its canonic representation and returns this
         string. This allows a user to refer to a given file in one of several
         equivalent ways.
 
@@ -181,7 +185,7 @@ class TrepanCore(object):
 
     def canonic_filename(self, frame):
         """Picks out the file name from `frame' and returns its
-         canonic() value, a string."""
+        canonic() value, a string."""
         return self.canonic(frame.f_code.co_filename)
 
     def filename(self, filename=None):
@@ -213,7 +217,7 @@ class TrepanCore(object):
         return self.ignore_filter.remove_include(frame_or_fn)
 
     def start(self, opts=None):
-        """ We've already created a debugger object, but here we start
+        """We've already created a debugger object, but here we start
         debugging in earnest. We can also turn off debugging (but have
         the hooks suspended or not) using 'stop'.
 
@@ -313,7 +317,7 @@ class TrepanCore(object):
         # condition evaluates to true.
         try:
             val = eval(self.until_condition, frame.f_globals, frame.f_locals)
-        except:
+        except Exception:
             # if eval fails, most conservative thing is to
             # stop on breakpoint regardless of ignore count.
             # Don't delete temporary, as another hint to user.
@@ -321,7 +325,7 @@ class TrepanCore(object):
         return val
 
     def is_stop_here(self, frame, event):
-        """ Does the magic to determine if we stop here and run a
+        """Does the magic to determine if we stop here and run a
         command processor or not. If so, return True and set
         self.stop_reason; if not, return False.
 
@@ -447,7 +451,7 @@ class TrepanCore(object):
         finally:
             try:
                 self.debugger_lock.release()
-            except:
+            except Exception:
                 pass
             pass
         pass
