@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2008-2009, 2013, 2015, 2017, 2020-2021 Rocky Bernstein
-#   <rocky@gnu.org>
+#
+#   Copyright (C) 2008-2009, 2013, 2015, 2017, 2020-2021, 2023 Rocky
+#   Bernstein <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -17,9 +18,10 @@
 """ A place for the debugger default settings """
 
 # External Egg packages
-import os, tracer
-from columnize import computed_displaywidth
+import os
 
+import tracer
+from columnize import computed_displaywidth
 from term_background import is_dark_background
 
 width = computed_displaywidth()
@@ -41,7 +43,7 @@ DEBUGGER_SETTINGS = {
     # updated information (stack, local variables) without having to
     # poll for it.
     "annotate": 0,
-    # Format style to use in showing disssembly
+    # Format style to use in showing disassembly
     "asmfmt": "extended",
     # Eval as Python the unrecognized debugger commands?
     "autoeval": True,
@@ -56,7 +58,7 @@ DEBUGGER_SETTINGS = {
     # Enter Python every time we enter the debugger?
     "autopython": False,
     # Show basename only on filename output?
-    # This opiton is useful in integration testing and
+    # This option is useful in integration testing and
     # possibly to prepare example output for publication
     "basename": False,
     # Set echoing lines read from debugger?
@@ -101,8 +103,8 @@ DEBUGGER_SETTINGS = {
     "nostartup": False,
     # Reread source file if we determine it has changed?
     "reload": False,
-    # Skip instructions that make clases, functions, and closures?
-    # (In the Python they are "class" and "def" statments)
+    # Skip instructions that make classes, functions, and closures?
+    # (In the Python they are "class" and "def" statements)
     "skip": True,
     "step_ignore": 0,
     # Location to put temporary decompiled python files.
@@ -124,7 +126,7 @@ CLIENT_SOCKET_OPTS = {
 SERVER_SOCKET_OPTS = {
     "HOST": None,  # Symbolic name meaning all available interfaces
     "PORT": 1027,  # Arbitrary non-privileged port
-    "reuse": "posix" == os.name,  # Allow port to be resued on close?
+    "reuse": "posix" == os.name,  # Allow port to be reused on close?
     "skew": +0,  # additional increment on socket tries
     "search_limit": 100,  # max number of ports to try
 }
