@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-#  Copyright (C) 2009, 2012-2018, 2020 Rocky Bernstein
+#
+#  Copyright (C) 2009, 2012-2018, 2020, 2023 Rocky Bernstein
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -14,15 +15,18 @@
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import inspect, sys
+import inspect
 import os.path as osp
+import sys
+
+from xdis.load import load_module
+
+import trepan.lib.file as Mfile
+from trepan.lib.disassemble import dis
+from trepan.processor.cmd_addrlist import parse_addr_list_cmd
 
 # Our local modules
 from trepan.processor.command.base_cmd import DebuggerCommand
-from trepan.lib.disassemble import dis
-import trepan.lib.file as Mfile
-from xdis.load import load_module
-from trepan.processor.cmd_addrlist import parse_addr_list_cmd
 
 # From importlib.util
 DEBUG_BYTECODE_SUFFIXES = [".pyc"]
@@ -66,50 +70,47 @@ def cache_from_source(path, debug_override=None):
 class DisassembleCommand(DebuggerCommand):
     """**disassemble** [*thing*]
 
-**disassemble** [*address-range*]
+    **disassemble** [*address-range*]
 
-Disassembles bytecode. See `help syntax range` for what can go in a list range.
+    Disassembles bytecode. See `help syntax range` for what can go in a list range.
 
-Without arguments, print lines starting from where the last list left off
-since the last entry to the debugger. We start off at the location indicated
-by the current stack.
+    Without arguments, print lines starting from where the last list left off
+    since the last entry to the debugger. We start off at the location indicated
+    by the current stack.
 
-in addition you can also use:
+    in addition you can also use:
 
-  - a '.' for the location of the current frame
+      - a '.' for the location of the current frame
 
-  - a '-' for the lines before the last list
+      - a '-' for the lines before the last list
 
-  - a '+' for the lines after the last list
+      - a '+' for the lines after the last list
 
-With a class, method, function, pyc-file, code or string argument
-disassemble that.
+    With a class, method, function, pyc-file, code or string argument
+    disassemble that.
 
-Examples:
---------
-::
+    Examples:
+    --------
+    ::
 
-   disassemble    # Possibly current frame
-   disassemble +                    # Same as above
-   disassemble os.path              # Disassemble all of os.path # xxx
-   disassemble os.path.normcase()   # Disaasemble just method os.path.normcase
-   disassemble 3                    # Disassemble starting from line 3
-   disassemble 3, 10                # Disassemble lines 3 to 10
-   disassemble *0, *10              # Disassemble offset 0..10 (10 not included)
-   disassemble myprog.pyc           # Disassemble file myprog.pyc
+       disassemble    # Possibly current frame
+       disassemble +                    # Same as above
+       disassemble os.path              # Disassemble all of os.path # xxx
+       disassemble os.path.normcase()   # Disaasemble just method os.path.normcase
+       disassemble 3                    # Disassemble starting from line 3
+       disassemble 3, 10                # Disassemble lines 3 to 10
+       disassemble *0, *10              # Disassemble offset 0..10 (10 not included)
+       disassemble myprog.pyc           # Disassemble file myprog.pyc
 
-See also:
----------
+    See also:
+    ---------
 
-`help syntax arange`, `deparse`, `list`, `info pc`.
-"""
+    `help syntax arange`, `deparse`, `list`, `info pc`."""
 
     aliases = ("disasm",)  # Note: we will have disable
     short_help = "Disassemble Python bytecode"
 
-    DebuggerCommand.setup(
-        locals(), category="data", max_args=2
-    )
+    DebuggerCommand.setup(locals(), category="data", max_args=2)
 
     def run(self, args):
         proc = self.proc
@@ -124,7 +125,7 @@ See also:
             "start_offset": None,
             "end_offset": None,
             "relative_pos": False,
-            "asm_format" : self.settings["asmfmt"]
+            "asm_format": self.settings["asmfmt"],
         }
 
         curframe = proc.curframe
@@ -141,7 +142,7 @@ See also:
                 eval_args = args[1]
             try:
                 obj = self.proc.eval(eval_args, show_error=False)
-            except:
+            except Exception:
                 obj = None
             else:
                 if (
@@ -205,7 +206,7 @@ See also:
                 try:
                     obj = self.proc.eval(args[1])
                     opts["start_line"] = -1
-                except:
+                except Exception:
                     self.errmsg(
                         ("Object '%s' is not something we can" + " disassemble.")
                         % args[1]
@@ -221,7 +222,6 @@ See also:
 
 # Demo it
 if __name__ == "__main__":
-
     # FIXME: make sure the below is in a unit test
     def doit(cmd, args):
         proc = cmd.proc
@@ -237,13 +237,13 @@ if __name__ == "__main__":
     prefix = "-" * 20 + " disassemble "
 
     print(prefix + "os.path")
-    doit(command, ["dissassemble", "cp.errmsg()"])
+    doit(command, ["disassemble", "cp.errmsg()"])
 
     print(prefix + "cp.errmsg()")
-    doit(command, ["dissassemble", "cp.errmsg()"])
+    doit(command, ["disassemble", "cp.errmsg()"])
 
     print(prefix + "cp.errmsg()")
-    doit(command, ["dissassemble", "cp.errmsg()"])
+    doit(command, ["disassemble", "cp.errmsg()"])
 
     # print(prefix)
     # doit(command, ['disassemble']) # no good
