@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2009, 2012-2017, 2020-2021 Rocky Bernstein
+#  Copyright (C) 2009, 2012-2017, 2020-2021, 2023 Rocky Bernstein
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -13,60 +13,64 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-import inspect, linecache, pyficache, sys
+import inspect
+import linecache
 import os.path as osp
+import sys
+
+import pyficache
 
 # Our local modules
 from pygments.console import colorize
 
+from trepan.lib.deparse import deparse_cache
+from trepan.processor.cmdlist import parse_list_cmd
+
 # Our local modules
 from trepan.processor.command.base_cmd import DebuggerCommand
-from trepan.processor.cmdlist import parse_list_cmd
-from trepan.lib.deparse import deparse_cache
 
 
 class ListCommand(DebuggerCommand):
     """**list** [ *range* ]
 
-**list**  **+** | **-** | **.**
+    **list**  **+** | **-** | **.**
 
-List source code. See `help syntax range` for what can go in a list range.
+    List source code. See `help syntax range` for what can go in a list range.
 
-Without arguments, print lines starting from where the last list left off
-since the last entry to the debugger. We start off at the location indicated
-by the current stack.
+    Without arguments, print lines starting from where the last list left off
+    since the last entry to the debugger. We start off at the location indicated
+    by the current stack.
 
-in addition you can also use:
+    in addition you can also use:
 
-  - a '.' for the location of the current frame
-  - a '-' for the lines before the last list
-  - a '+' for the lines after the last list
+      - a '.' for the location of the current frame
+      - a '-' for the lines before the last list
+      - a '+' for the lines after the last list
 
-Examples:
---------
+    Examples:
+    --------
 
-    list 5               # List starting from line 5 of current file
-    list 5 ,             # Same as above.
-    list , 5             # list listsize lines before and up to 5
-    list foo.py:5        # List starting from line 5 of file foo.py
-    list foo()           # List starting from function foo
-    list os.path:5       # List starting from line 5 of module os.path
-    list os.path:5, 6    # list lines 5 and 6 of os.path
-    list os.path:5, +1   # Same as above. +1 is an offset
-    list os.path:5, 1    # Same as above, since 1 < 5.
-    list os.path:5, +6   # list lines 5-11
-    list os.path.join()  # List lines centered around the os.join.path function.
-    list .               # List lines centered from where we currently are stopped
-    list -               # List lines previous to those just shown
-    list                 # List continuing from where we last left off
+        list 5               # List starting from line 5 of current file
+        list 5 ,             # Same as above.
+        list , 5             # list listsize lines before and up to 5
+        list foo.py:5        # List starting from line 5 of file foo.py
+        list foo()           # List starting from function foo
+        list os.path:5       # List starting from line 5 of module os.path
+        list os.path:5, 6    # list lines 5 and 6 of os.path
+        list os.path:5, +1   # Same as above. +1 is an offset
+        list os.path:5, 1    # Same as above, since 1 < 5.
+        list os.path:5, +6   # list lines 5-11
+        list os.path.join()  # List lines centered around the os.join.path function.
+        list .               # List lines centered from where we currently are stopped
+        list -               # List lines previous to those just shown
+        list                 # List continuing from where we last left off
 
-See also:
----------
+    See also:
+    ---------
 
-`set listize` or `show listsize` to see or set the value; `help syntax location`
-for the specification of a location and `help syntax range` for the specification
-of a range.
-"""
+    `set listize` or `show listsize` to see or set the value; `help syntax location`
+    for the specification of a location and `help syntax range` for the specification
+    of a range."""
 
     aliases = ("l",)
     short_help = "List source code"
@@ -135,8 +139,16 @@ of a range.
                     s = proc._saferepr(lineno).rjust(3)
                     if len(s) < 5:
                         s += " "
-                    if (canonic_filename, lineno,) in list(bplist.keys()):
-                        bp = bplist[(canonic_filename, lineno,)][0]
+                    if (
+                        canonic_filename,
+                        lineno,
+                    ) in list(bplist.keys()):
+                        bp = bplist[
+                            (
+                                canonic_filename,
+                                lineno,
+                            )
+                        ][0]
                         a_pad = "%02d" % bp.number
                         s += bp.icon_char()
                     else:
@@ -161,15 +173,14 @@ of a range.
 
 
 if __name__ == "__main__":
-
     # FIXME: make sure the below is in a unit test
     def doit(cmd, args):
         proc = cmd.proc
         proc.current_command = " ".join(args)
         cmd.run(args)
 
-    from trepan.processor.command import mock as Mmock
     from trepan.processor.cmdproc import CommandProcessor
+    from trepan.processor.command import mock as Mmock
 
     d = Mmock.MockDebugger()
     cmdproc = CommandProcessor(d.core)
